@@ -21,15 +21,6 @@
   (format *stderr* "~%~NC~%test: port-length=32 etc~%" 80 #\-)
   (system (string-append "./repl " aux-file)))
 
-(let ((aux-file (format #f "t101-aux-~D.scm" (set! aux-counter (+ aux-counter 1)))))
-  (call-with-output-file aux-file
-    (lambda (p)
-      (format p "(define aux-counter ~D)\n" aux-counter)
-      (format p "(with-input-from-file \"/home/bil/cl/all-lg-results\" (lambda () (display (with-output-to-string (lambda () (load \"s7test.scm\")))) (newline)))")
-      (format p "(load \"s7test.scm\")~%(exit)~%")))
-  (format *stderr* "~%~NC~%test: stdin from all-lg-results~%" 80 #\-)
-  (system (string-append "./repl " aux-file)))
-
 (for-each
  (lambda (test-case)
    (let ((aux-file (format #f "t101-aux-~D.scm" (set! aux-counter (+ aux-counter 1)))))
@@ -161,21 +152,7 @@
     
 
 (format *stderr* "~%~NC lint ~NC~%" 20 #\- 20 #\-)
-(catch #t (lambda () (lint "s7test.scm" #f)) (lambda args #f))
-
-;; lint clobbers reader-cond
-(define-expansion (reader-cond . clauses)
-  (call-with-exit
-   (lambda (return)
-     (for-each
-      (lambda (clause)
-	(let ((val (eval (car clause))))
-	  (if val
-	      (if (null? (cdr clause)) (return val)
-		  (if (null? (cddr clause)) (return (cadr clause))
-		      (return (apply values (map quote (cdr clause)))))))))
-      clauses)
-     (values))))
+(catch #t (lambda () (lint "snd-test.scm" #f)) (lambda (type info) (apply format #t info)))
 
 ;(format *stderr* "~%~NC local s7test ~NC~%" 20 #\- 20 #\-)
 ;(system "./snd -e '(let () (catch #t (lambda () (load \"s7test.scm\" (curlet))) (lambda args #f)) (exit))'")
@@ -309,9 +286,6 @@
 (format *stderr* "~NC bench ~NC~%" 20 #\- 20 #\-)
 (system "(cd /home/bil/test/scheme/bench/src ; /home/bil/cl/repl test-all.scm)")
 
-;(format *stderr* "~NC lg ~NC~%" 20 #\- 20 #\-)
-;(system "./repl lg.scm")
-
 (format *stderr* "~NC full s7test ~NC~%" 20 #\- 20 #\-)
 (system "./repl full-s7test.scm")
 
