@@ -157,7 +157,7 @@
 	    (let ((bottom (car argn))
 		  (top (min (cdr argn) max-args))
 		  (strname (symbol->string sym)))
-	      (unless (memv (strname 0) '(#\{ #\[ #\())
+	      ;(unless (memv (strname 0) '(#\{ #\[ #\()) ; no longer relevant, setters start with #<, none with {
 		(if (< top bottom)
 		    (format *stderr* ";~A (bottom: ~A, top: ~A)...~%" sym bottom top))
 		(set! low bottom)
@@ -167,7 +167,7 @@
 					(set-cdr! lst lst)))
 				     (else (copy (signature f))))))
 		      (map-values sig)
-		      (autotest f () 0 top (if (pair? sig) (cdr sig) ()))))))))))
+		      (autotest f () 0 top (if (pair? sig) (cdr sig) ())))))))));)
   
   (define (all)
     (let ((st (symbol-table)))
@@ -326,7 +326,7 @@
 		    delete-file system set-cdr! stacktrace check check-funcs type-ok
 		    cutlet varlet gc cond-expand reader-cond
 		    openlet coverlet eval ;vector list cons values hash-table
-		    symbol-table load throw error
+		    symbol-table load throw error show-stack
 		    make-rectangular macro macro* bacro bacro*
 		    copy fill! hash-table-set! vector-set! let-set! list-values apply-values immutable!
 		    *unbound-variable-hook* *load-hook* *rootlet-redefinition-hook* *missing-close-paren-hook* *read-error-hook*
