@@ -180,20 +180,20 @@
       (num-test (gsl_sf_gegenpoly_1 1.0 1.0) 2.0)
       
       (let ((p (float-vector 1.0 -2.0 1.0)) (res (vector 0.0 0.0)))
-	(gsl_poly_complex_solve (double* p) 3 res)
+	(gsl_poly_complex_solve (wrap-double* p) 3 res)
 	(test res #(1.0 1.0)))
       (let ((p (float-vector 1 -1 1 -1 1 -1 1 -1 1 -1 1)))
-	(num-test (gsl_poly_eval (double* p) 11 1.0) 1.0))
+	(num-test (gsl_poly_eval (wrap-double* p) 11 1.0) 1.0))
       (let ((p (float-vector 2.1 -1.34 0.76 0.45)))
-	(num-test (gsl_poly_complex_eval (double* p) 4 0.49+0.95i) 0.3959142999999998-0.6433305000000001i))
+	(num-test (gsl_poly_complex_eval (wrap-double* p) 4 0.49+0.95i) 0.3959142999999998-0.6433305000000001i))
       (let ((res (float-vector 0.0 0.0)))
-	(let ((err (gsl_poly_solve_quadratic 4.0 -20.0 26.0 (double* res))))
+	(let ((err (gsl_poly_solve_quadratic 4.0 -20.0 26.0 (wrap-double* res))))
 	  (test err 0)))
       (let ((res (float-vector 0.0 0.0)))
-	(let ((err (gsl_poly_solve_quadratic 4.0 -20.0 21.0 (double* res))))
+	(let ((err (gsl_poly_solve_quadratic 4.0 -20.0 21.0 (wrap-double* res))))
 	  (test res (float-vector 1.5 3.5))))
       (let ((res (float-vector 0.0 0.0 0.0)))
-	(let ((err (gsl_poly_solve_cubic -51 867 -4913 (double* res))))
+	(let ((err (gsl_poly_solve_cubic -51 867 -4913 (wrap-double* res))))
 	  (test res (float-vector 17.0 17.0 17.0))))
       (let ((res (vector 0.0 0.0)))
 	(let ((err (gsl_poly_complex_solve_quadratic 4.0 -20.0 26.0 res)))
@@ -233,9 +233,9 @@
       (num-test (gsl_cdf_beta_P 0 1.2 1.3) 0.0)
       (num-test (gsl_cdf_beta_Q 0 1.2 1.3) 1.0)
       
-      (num-test (gsl_stats_mean (double* (float-vector 1.0 2.0 3.0 4.0)) 1 4) 2.5)
-      (num-test (gsl_stats_skew (double* (float-vector 1.0 2.0 3.0 4.0)) 1 4) 0.0)
-      (num-test (gsl_stats_max (double* (float-vector 1.0 2.0 3.0 4.0)) 1 4) 4.0)
+      (num-test (gsl_stats_mean (wrap-double* (float-vector 1.0 2.0 3.0 4.0)) 1 4) 2.5)
+      (num-test (gsl_stats_skew (wrap-double* (float-vector 1.0 2.0 3.0 4.0)) 1 4) 0.0)
+      (num-test (gsl_stats_max (wrap-double* (float-vector 1.0 2.0 3.0 4.0)) 1 4) 4.0)
       
       (let ((rng (gsl_rng_alloc gsl_rng_default)))
 	(test (real? (gsl_ran_exponential rng 1.0)) #t)
@@ -254,13 +254,13 @@
       
       (let ((x (float-vector 0.0))
 	    (y (float-vector 0.0)))
-	(gsl_deriv_central (lambda (x) (expt x 1.5)) 2.0 1e-8 (double* x) (double* y))
+	(gsl_deriv_central (lambda (x) (expt x 1.5)) 2.0 1e-8 (wrap-double* x) (wrap-double* y))
 	(num-test (x 0) (* 1.5 (sqrt 2)))
-	(gsl_deriv_forward (lambda (x) (expt x 1.5)) 0.0 1e-8 (double* x) (double* y))
+	(gsl_deriv_forward (lambda (x) (expt x 1.5)) 0.0 1e-8 (wrap-double* x) (wrap-double* y))
 	(test (< (x 0) 1e-5) #t))
       
       (let ((f (float-vector -1 3 0 4 2 6)))
-	(gsl_sort (double* f) 1 6)
+	(gsl_sort (wrap-double* f) 1 6)
 	(test f (float-vector -1 0 2 3 4 6)))
       
       (let ((g1 (gsl_vector_alloc 3))
@@ -299,7 +299,7 @@
       (let ((Y (float-vector 0.554))
 	    (A (float-vector -0.047))
 	    (X (float-vector 0.672)))
-	(cblas_dgemv 101 111 1 1 -0.3 (double* A) 1 (double* X) -1 -1 (double* Y) -1)
+	(cblas_dgemv 101 111 1 1 -0.3 (wrap-double* A) 1 (wrap-double* X) -1 -1 (wrap-double* Y) -1)
 	(num-test (Y 0) -0.5445248))
       
       (let ((Y (float-vector 0.348 0.07))
@@ -307,11 +307,11 @@
 	    (X (float-vector 0.334 -0.317))
 	    (alpha (float-vector 0 .1))
 	    (beta (float-vector 1 0)))
-	(cblas_zgemv 101 111 1 1 (double* alpha) (double* A) 1 (double* X) -1 (double* beta) (double* Y) -1)
+	(cblas_zgemv 101 111 1 1 (wrap-double* alpha) (wrap-double* A) 1 (wrap-double* X) -1 (wrap-double* beta) (wrap-double* Y) -1)
 	(num-test (Y 0) 0.401726)
 	(num-test (Y 1) 0.078178))
       
-      (test (let ((f (float-vector 0 1 2 3 4))) (gsl_interp_bsearch (double* f) 1.5 0 4)) 1)
+      (test (let ((f (float-vector 0 1 2 3 4))) (gsl_interp_bsearch (wrap-double* f) 1.5 0 4)) 1)
       
       (let ((x (make-float-vector 10))
 	    (y (make-float-vector 10)))
@@ -321,7 +321,7 @@
 	  (set! (y i) (+ i (cos (* i i)))))
 	(let ((acc (gsl_interp_accel_alloc))
 	      (spline (gsl_spline_alloc gsl_interp_cspline 10)))
-	  (gsl_spline_init spline (double* x) (double* y) 10)
+	  (gsl_spline_init spline (wrap-double* x) (wrap-double* y) 10)
 	  (let ((res (gsl_spline_eval spline (x 5) acc)))
 	    (gsl_spline_free spline)
 	    (gsl_interp_accel_free acc)
@@ -364,17 +364,17 @@
 	    (let ((accel (float-vector 0.0))
 		  (err (float-vector 0.0))
 		  (w (gsl_sum_levin_u_alloc N)))
-	      (gsl_sum_levin_u_accel (double* t) N w (double* accel) (double* err))
+	      (gsl_sum_levin_u_accel (wrap-double* t) N w (wrap-double* accel) (wrap-double* err))
 	      (num-test zeta_2 (accel 0))
 	      (gsl_sum_levin_u_free w)))))
       
       (let ((data (float-vector 0 0  1 0  1 1  0 -1)) ; complex data as rl+im coming and going
 	    (output (make-float-vector 8 0.0)))
-	(gsl_dft_complex_forward (double* data) 1 4 (double* output))
+	(gsl_dft_complex_forward (wrap-double* data) 1 4 (wrap-double* output))
 	;; = -1 in snd terminology: (cfft! (vector 0 1 1+i 0-i) 4 -1): #(2.0 0-2i 0+2i -2.0)
 	(test (equivalent? output (float-vector 2.0 0.0  0.0 -2.0  0.0 2.0  -2.0 0.0)) #t))
       (let ((data (float-vector 0 0  1 0  1 1  0 -1))) ; complex data as rl+im coming and going
-	(gsl_fft_complex_radix2_forward (double* data) 1 4)
+	(gsl_fft_complex_radix2_forward (wrap-double* data) 1 4)
 	(test (equivalent? data (float-vector 2.0 0.0  0.0 -2.0  0.0 2.0  -2.0 0.0)) #t))
       
       (let ((data (make-float-vector 256))
@@ -383,8 +383,8 @@
 	(do ((i 0 (+ i 1)))
 	    ((= i 256))
 	  (set! (data i) (sin (* i (/ pi 128)))))
-	(gsl_wavelet_transform_forward w (double* data) 1 256 work)
-	(gsl_wavelet_transform_inverse w (double* data) 1 256 work)
+	(gsl_wavelet_transform_forward w (wrap-double* data) 1 256 work)
+	(gsl_wavelet_transform_inverse w (wrap-double* data) 1 256 work)
 	(gsl_wavelet_free w)
 	(gsl_wavelet_workspace_free work)
 	data)
@@ -473,8 +473,8 @@
 		    (y_err (float-vector 0.0)))
 		(gsl_vector_set gv 0 (gsl_matrix_get X i 0))
 		(gsl_vector_set gv 1 (gsl_matrix_get X i 1))
-		(gsl_multifit_robust_est gv c cov (double* y_rob) (double* y_err))
-		(gsl_multifit_robust_est gv c_ols cov (double* y_ols) (double* y_err))))
+		(gsl_multifit_robust_est gv c cov (wrap-double* y_rob) (wrap-double* y_err))
+		(gsl_multifit_robust_est gv c_ols cov (wrap-double* y_ols) (wrap-double* y_err))))
 	    (gsl_matrix_free X)
 	    (gsl_matrix_free cov)
 	    (gsl_vector_free x)
@@ -493,7 +493,7 @@
 	       (dy (float-vector 0.0)))
 	  (do ((i 0 (+ i 1)))
 	      ((= i 10))
-	    (gsl_ran_dir_2d r (double* dx) (double* dy))
+	    (gsl_ran_dir_2d r (wrap-double* dx) (wrap-double* dy))
 	    (set! x (+ x (dx 0)))
 	    (set! y (+ y (dy 0))))
 	  (gsl_rng_free r)))
@@ -533,8 +533,8 @@
 	    (cov01 (float-vector 0.0))
 	    (cov11 (float-vector 0.0))
 	    (chisq (float-vector 0.0)))
-	(gsl_fit_wlinear (double* x) 1 (double* w) 1 (double* y) 1 n
-			 (double* c0) (double* c1) (double* cov00) (double* cov01) (double* cov11) (double* chisq))
+	(gsl_fit_wlinear (wrap-double* x) 1 (wrap-double* w) 1 (wrap-double* y) 1 n
+			 (wrap-double* c0) (wrap-double* c1) (wrap-double* cov00) (wrap-double* cov01) (wrap-double* cov11) (wrap-double* chisq))
 	(num-test (+ (c0 0) (c1 0)) -106.54))
       
       (let ((c (gsl_multiset_calloc 4 2)))
