@@ -89,7 +89,7 @@
 ;;; --------------------------------------------------------------------------------
 
 (define (cat)
-  (let ((inport (open-input-file "/home/bil/cl/all-lg-results"))
+  (let ((inport (open-input-file "/home/bil/cl/s7test.scm"))
 	(outport (open-output-file "/dev/null"))) 
     (catch #t
       (lambda ()
@@ -99,7 +99,9 @@
 	(close-input-port inport)
 	(close-output-port outport)))))
 
-(cat)
+(do ((i 0 (+ i 1)))
+    ((= i 12))
+  (cat))
 
 ;;; --------------------------------------------------------------------------------
 
