@@ -16,7 +16,6 @@
 		     ("tmap.scm" . "v-map")
 		     ("tmat.scm" . "v-mat")
 		     ("tmisc.scm" . "v-misc")
-		     ("lg.scm" . "v-lg")
 		     ("titer.scm" . "v-iter")
 		     ("tsort.scm" . "v-sort")
 		     ("tlet.scm" . "v-let")
@@ -108,8 +107,8 @@
 	 (list "repl" "teq.scm")
 	 (list "repl" "tio.scm")
 	 (list "repl" "tmac.scm")
-	 (list "repl" "tclo.scm")
 	 (list "repl" "tcase.scm")
+	 (list "repl" "tclo.scm")
 	 (list "repl" "tlet.scm")
 	 (list "repl" "tfft.scm")
 	 (list "repl" "tstar.scm")
@@ -122,8 +121,8 @@
 	 (list "repl" "tmisc.scm")
 	 (list "repl" "tgsl.scm")
 	 (list "repl" "tlist.scm")
-	 (list "repl" "tset.scm")
 	 (reader-cond ((not (provided? 'gmp)) (list "repl" "tari.scm")))
+	 (list "repl" "tset.scm")
 	 (list "repl" "trec.scm")
 	 (list "repl" "tleft.scm")
 	 (list "repl" "tgc.scm")
@@ -133,7 +132,6 @@
 	 (list "snd -noinit" "tall.scm")
 	 (list "snd -l" "snd-test.scm")
 	 (list "snd -l" "full-snd-test.scm")
-	 (list "repl" "lg.scm")
 	 (list "repl" "tbig.scm")
 	 )))
 
